==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/sortable-list/sortable-list.js <==
import React from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import Sortable from 'react-sortablejs';
import {XlReactWidgetWithPopup} from '../../xl-react-widget/xl-react-widget-with-popup/xl-react-widget-with-popup';
import {localeMessages} from '../../services/locale-service';
import {nextId} from '../../utils/id-generator';
import '../../images/grab-handle.svg';

const SortableList = ({disabled, canSort, indexedItems = [], onChange, remove}) => {
    const handleRemove = (index) => () => remove(index);

    const removeButton = (index) =>
        disabled ?
            null :
            <span className="xl-react-btn-close" onClick={handleRemove(index)}/>;

    const listItems = R.map((current) => {
        const {message = localeMessages.invalidItem, model: [val, index], valid} = current;
        return <li className="xl-list-row" data-id={val} key={index}>
            <span className="ui-sortable-handler-icon"/>
            {!valid && <XlReactWidgetWithPopup
                popoverContent={message}
                popoverid={nextId()}>
                <span className="ui-sortable-handle-invalid"/>
            </XlReactWidgetWithPopup>}
            <span className="text-container" title={val}>{val}</span>
            {removeButton(index)}
        </li>;
    }, indexedItems);

    const disabledList = <ul>
        {listItems}
    </ul>;

    const sortableList = <Sortable className={canSort && 'ui-sortable'} onChange={onChange} tag="ul">
        {listItems}
    </Sortable>;

    return canSort ? sortableList : disabledList;
};

SortableList.propTypes = {
    canSort: PropTypes.bool,
    disabled: PropTypes.bool,
    indexedItems: PropTypes.array,
    onChange: PropTypes.func,
    remove: PropTypes.func
};

export default SortableList;

==> xl-react-components-0.21.12.tgz: package/app/xl-react-dip/sortable-list/sortable-list.js <==
import React from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {ReactSortable} from 'react-sortablejs';
import {XlReactWidgetWithPopup} from '../../xl-react-widget/xl-react-widget-with-popup/xl-react-widget-with-popup';
import {localeMessages} from '../../services/locale-service';
import {nextId} from '../../utils/id-generator';

const SortableList = ({disabled, canSort, indexedItems = [], remove}) => {
    const handleRemove = (index) => () => remove(index);

    const removeButton = (index) =>
        disabled ?
            null :
            <i className="xl-icon close-icon" onClick={handleRemove(index)}/>;

    const listItems = R.map((current) => {
        const {message = localeMessages.invalidItem, model: [val, index], valid} = current;
        return <li className="xl-list-row" data-value={val} key={index}>
            {canSort && <span className="xl-icon drag-vertical-icon"/>}
            {!valid && <XlReactWidgetWithPopup
                popoverContent={message}
                popoverid={nextId()}>
                <i className="xl-icon warning-icon"/>
            </XlReactWidgetWithPopup>}
            <span className="text-container" title={val}>{val}</span>
            {removeButton(index)}
        </li>;
    }, indexedItems);

    const disabledList = <ul>
        {listItems}
    </ul>;

    const sortableList = <ReactSortable
        className={canSort && 'ui-sortable'}
        list={indexedItems}
        setList={R.F}
        tag="ul">
        {listItems}
    </ReactSortable>;

    return canSort ? sortableList : disabledList;
};

SortableList.propTypes = {
    canSort: PropTypes.bool,
    disabled: PropTypes.bool,
    indexedItems: PropTypes.array,
    onChange: PropTypes.func,
    remove: PropTypes.func
};

export default SortableList;
